#include <QCoreApplication>
#include <QFileSystemWatcher>
#include <QFile>
#include <QTemporaryDir>
#include <QObject>
#include <QString>
#include <QTimer>

class Test : public QObject {
    Q_OBJECT
public:

    Test() {
        filePath = dir.filePath("test.txt");

        // create file once
        touchFile();

        // now watch
        qDebug("Watching file %s ...", qUtf8Printable(filePath));
        watcher.addPath(filePath);

        connect(&watcher, &QFileSystemWatcher::fileChanged, this, &Test::fileChanged);

        connect(&t, &QTimer::timeout, this, &Test::touchFile);
        t.start(1000);
    }

public slots:
    void touchFile() {
        QFile f(filePath);
        static int i = 0;
        if (f.open(QIODevice::WriteOnly | QIODevice::Truncate | QIODevice::Text)) {
            qDebug("Touching file %s", qUtf8Printable(filePath));
            f.write(QString("Hello World %1\n").arg(i).toUtf8());
        } else {
            qFatal("Cannot open file %s!", qUtf8Printable(filePath));
        }
    }

    void fileChanged(const QString &path) {
        qInfo("File %s changed", qUtf8Printable(path));
    }

private:
    QTemporaryDir dir;
    QString filePath;
    QFileSystemWatcher watcher;
    QTimer t;
};

int main(int argc, char *argv[])
{
    QCoreApplication a(argc, argv);

    Test test;
    return a.exec();
}

#include "main.moc"
